# This R script documents how the Linear Mixed Models analyses described 
# in the ICPR paper were performed. It needs some modifications to run
# properly; check the comments below.


# uncomment if you get errors about missing packages:
# install.packages('reticulate', 'lme4')

library("reticulate")
library("lme4")

# uncomment if you can't load the pandas dataframe:
# py_install("pandas")

# here you will be asked to enter the path to observations_sp24_0.5.pkl, 
# created by export_dataframe_for_r() in salami_proc_usage.py
# you can also replace readline() with the path in the script, of course..
pathtopickle <- readline(prompt="Enter path to observations pickle file: ")
data <- py_load_object(pathtopickle)

# fits full model with all fixed effects
model.full = lmer(score ~ msi_experience + lang_fit + environment + academic_level +
    (1 | user_id) + (1 | unit_id), data=data, REML=FALSE)

# fits models with each one fixed effect missing 
model.wo.msi_experience = lmer(score ~ lang_fit + environment + academic_level +
    (1 | user_id) + (1 | unit_id), data=data, REML=FALSE)
model.wo.lang_fit = lmer(score ~ msi_experience + environment + academic_level +
    (1 | user_id) + (1 | unit_id), data=data, REML=FALSE)
model.wo.environment  = lmer(score ~ msi_experience + lang_fit + academic_level +
    (1 | user_id) + (1 | unit_id), data=data, REML=FALSE)
model.wo.academic_level = lmer(score ~ msi_experience + lang_fit + environment +
    (1 | user_id) + (1 | unit_id), data=data, REML=FALSE)

# compares full model with each of the reduced ones to check for significance
anova(model.full, model.wo.msi_experience)
anova(model.full, model.wo.lang_fit)
anova(model.full, model.wo.environment)
anova(model.full, model.wo.academic_level)

# shows details of full model
summary(model.full)